==> openlitespeed_1.2.11.orig.tar.gz: openlitespeed-1.2.11/src/socket/tcpserversocket.h <==
/*****************************************************************************
*    Open LiteSpeed is an open source HTTP server.                           *
*    Copyright (C) 2013  LiteSpeed Technologies, Inc.                        *
*                                                                            *
*    This program is free software: you can redistribute it and/or modify    *
*    it under the terms of the GNU General Public License as published by    *
*    the Free Software Foundation, either version 3 of the License, or       *
*    (at your option) any later version.                                     *
*                                                                            *
*    This program is distributed in the hope that it will be useful,         *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
*    GNU General Public License for more details.                            *
*                                                                            *
*    You should have received a copy of the GNU General Public License       *
*    along with this program. If not, see http://www.gnu.org/licenses/.      *
*****************************************************************************/
#ifndef TCPSERVERSOCKET_H
#define TCPSERVERSOCKET_H

#include <socket/serversocket.h>
#include <netinet/tcp.h>

// class TcpConnection;
// 
// class TcpServerSocket : public ServerSocket
// {
// public: 
//     TcpServerSocket() : ServerSocket( PF_INET ) {}
// 
//     TcpServerSocket( struct sockaddr * pAddr, int backlog = 10 );
//     ~TcpServerSocket(){};
// 
//     int     listen( struct sockaddr * pAddr, int backlog );
//     int     setDeferAccept( int defer )
//         {
// #ifdef TCP_DEFER_ACCEPT
//             return setTcpSockOptInt( TCP_DEFER_ACCEPT, defer );
// #else
//             return CoreSocket::SUCCESS;
// #endif
//         }
//     TcpConnection* acceptConn( TcpConnection& conn );
// };

#endif

==> openlitespeed14_1.4.25.orig.tar.gz: openlitespeed-1.4.25/src/socket/tcpserversocket.h <==
/*****************************************************************************
*    Open LiteSpeed is an open source HTTP server.                           *
*    Copyright (C) 2013 - 2015  LiteSpeed Technologies, Inc.                 *
*                                                                            *
*    This program is free software: you can redistribute it and/or modify    *
*    it under the terms of the GNU General Public License as published by    *
*    the Free Software Foundation, either version 3 of the License, or       *
*    (at your option) any later version.                                     *
*                                                                            *
*    This program is distributed in the hope that it will be useful,         *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
*    GNU General Public License for more details.                            *
*                                                                            *
*    You should have received a copy of the GNU General Public License       *
*    along with this program. If not, see http://www.gnu.org/licenses/.      *
*****************************************************************************/
#ifndef TCPSERVERSOCKET_H
#define TCPSERVERSOCKET_H

// #include <socket/serversocket.h>
// #include <netinet/tcp.h>

// class TcpConnection;
//
// class TcpServerSocket : public ServerSocket
// {
// public:
//     TcpServerSocket() : ServerSocket( PF_INET ) {}
//
//     TcpServerSocket( struct sockaddr * pAddr, int backlog = 10 );
//     ~TcpServerSocket(){};
//
//     int     listen( struct sockaddr * pAddr, int backlog );
//     int     setDeferAccept( int defer )
//         {
// #ifdef TCP_DEFER_ACCEPT
//             return setTcpSockOptInt( TCP_DEFER_ACCEPT, defer );
// #else
//             return CoreSocket::SUCCESS;
// #endif
//         }
//     TcpConnection* acceptConn( TcpConnection& conn );
// };

#endif
